@@ -2,7 +2,7 @@
                           kledtoggle.h  -  description
                              -------------------
     begin                : Sat Jan 26 2002
-    copyright            : (C) 2002 by Aurelien Jarno
+    copyright            : (C) 2002-2003 by Aurelien Jarno
     email                : aurelien@aurel32.net
  ***************************************************************************/
 
@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef KLEDTOGGLE_H
-#define KLEDTOGGLE_H
+#ifndef KLedTOGGLE_H
+#define KLedTOGGLE_H
 
 #ifdef HAVE_CONFIG_H
   #include <config.h>
